package SPVM::HTTP::Tiny::URL;



1;

=head1 Name

SPVM::HTTP::Tiny::URL - URL

=head1 Description

The HTTP::Tiny::URL class of L<SPVM> has methods to manipulate URL.

This class is a private class.

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

